*                          MICRON HSPICE MODEL
*
* Disclaimer:    This software code and all associated documentation, comments
*                or other information (collectively "Software") is provided
*                "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*                ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*                INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*                RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*                FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*                SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*                THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*                MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*                RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*                ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*                OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*                EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*                LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*                SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*                OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*                ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*                EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*                Because some jurisdictions prohibit the exclusion or limitation
*                of liability for consequential or incidental damages, the above
*                limitation may not apply to you.
*
*                Copyright 2003 Micron Technology, Inc. All rights reserved.
*
********************* 32Mx4, 16Mx8, and 8Mx16 3.3V SDRAM **********************
************************* HSPICE setup for DQ *********************************

***********************************************************
****           ____                                       *
****      IN--|    \                                      *
****          |     }------PAD--\/\/\/--@@@@--|--PKG_OUT  *
****  EN_OUT--|____/    |       R_pkg   L_pkg |           *
****                    |                    ===C_pkg     *
****             ___    |                     |           *
****            /   |---|                    GND          *
**** RCVR_OUT--{    |                                     *
****            \___|-(EN_OUT#)                           *
****                                                      *
***********************************************************

**** This netlist is for the x4, x8, and x16 128Mb 3.3V SDRAM *****************
**** The input signals are IN (input signal) and EN_OUT (output enable signal).
**** The I/O data is available on the signal PAD.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values,
**** netlist elements R_pkg, L_pkg, and C_pkg have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.

**** NOTE: This spice file is not designed to match datasheet timing numbers.
****       Delay times are smaller than those given in the data sheets.

**** The MOS models selected for this netlist are SS, TT, FF.
*       The different possible modes are
*       TT-- Typical N, Typical P
*       SS-- Slow N, Slow P
*       FF-- Fast N, Fast P
*       SF-- Slow N, Fast P
*       FS-- Fast N, Slow P
**** To run this simulation, the files "model.cnr" and "dqbuff.inc" are
**** required to be in the same directory as this netlist.
**** Temperature settings are: Typical 40C, Slow 100C, Fast -40C
****   These temperatures correspond to ambient temperatures of 25C, 85C, -40C.

.OPTIONS ACCT OPTS NOPAGE POST
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.05ns 20.0ns
**** The temperature is for the slow case
.TEMP 100
.LIB "model.cnr" SS

**** Input Signal and Power Supply Setup
**** Note: vccr, vccp, and vbb are regulated internal voltages
**** Match up typ, min, or max voltages for corner sims
.PARAM  vcc_typ    = 3.300V
.PARAM  vcc_min    = 3.000V
.PARAM  vcc_max    = 3.600V

.PARAM  vccq_typ   = 3.300V
.PARAM  vccq_min   = 3.000V
.PARAM  vccq_max   = 3.600V

.PARAM  vccr_typ   = 2.513V
.PARAM  vccr_min   = 2.431V
.PARAM  vccr_max   = 2.594V

.PARAM  vccp_typ   = 4.092V
.PARAM  vccp_min   = 3.941V
.PARAM  vccp_max   = 4.241V

.PARAM  vbb_typ    = -0.764V
.PARAM  vbb_min    = -0.828V
.PARAM  vbb_max    = -0.656V

.PARAM  gnd       = 0.0V
.PARAM  vssq      = 0.0V
********************************************************************************
.PARAM  vcc       = vcc_min
.PARAM  vccq      = vccq_min
.PARAM  vccr      = vccr_min
.PARAM  vccp      = vccp_min
.PARAM  vbb       = vbb_min
********************************************************************************
Vvcc    vcc   0  DC = vcc
Vvccq   vccq  0  DC = vccq
Vvccr   vccr  0  DC = vccr
Vvccp   vccp  0  DC = vccp
Vvbb    vbb   0  DC = vbb
Vvssq   vssq  0  DC = vssq

Ven    en_out  0  DC = vccr
** Enable signal is active high for output and active low for input

Vin     in    0  PWL 0.0ns vccr 0.1ns gnd 7.0ns gnd 7.1ns vccr 14.0ns vccr R
** Vin toggles the DQ from 1 to 0 at ~143Mhz/2 = 71.5MHz

* top cell:  dq
* *********************************************
* Output load circuits:
xi0 en_out in pad rcvr_out gnd vbb vccr vccp vccq vssq dqbuff

* Refer to the IBIS model for specific package parasitic values.
r_pkg pad net1 r=350e-3
l_pkg net1 pkg_out l=5.60e-9
c_pkg pkg_out gnd c=0.82e-12

.alter typ
.PARAM  vcc         = vcc_typ
.PARAM  vccq        = vccq_typ
.PARAM  vccr        = vccr_typ
.PARAM  vccp        = vccp_typ
.PARAM  vbb         = vbb_typ
.temp 40
.lib "model.cnr" TT

.alter fast
.PARAM  vcc         = vcc_max
.PARAM  vccq        = vccq_max
.PARAM  vccr        = vccr_max
.PARAM  vccp        = vccp_max
.PARAM  vbb         = vbb_max
.temp -40
.lib "model.cnr" FF

.END
