*                          MICRON HSPICE MODEL
*
* Disclaimer:    This software code and all associated documentation, comments
*                or other information (collectively "Software") is provided
*                "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*                ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*                INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*                RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*                FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*                SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*                THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*                MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*                RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*                ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*                OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*                EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*                LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*                SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*                OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*                ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*                EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*                Because some jurisdictions prohibit the exclusion or limitation
*                of liability for consequential or incidental damages, the above
*                limitation may not apply to you.
*
*                Copyright 2003 Micron Technology, Inc. All rights reserved.
*
********************* 32Mx4, 16Mx8, and 8Mx16 3.3V SDRAM **********************
*********** HSPICE setup for all address inputs, CAS, RAS, BA0 and BA1 ********

************************************************************
****             ___                                       *
****            /   |------PAD----\/\/\/--@@@@-----IN_PKG  *
**** RCVR_OUT--{    |             R_pkg  L_pkg |           *
****            \___|------RCVR_EN            ===C_pkg     *
****                                           |           *
****                                          GND          *
****                                                       *
************************************************************

**** This netlist is for the x4, x8, and x16 128Mb 3.3V SDRAM *****************
**** The input signal is IN_PKG (input signal).
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values,
**** netlist elements r_pkg, l_pkg, and c_pkg have been attached to the PAD node.

**** The MOS models selected for this netlist are SS, TT, FF.
****   The different possible modes are
****     TT-- Typical N, Typical P
****     SS-- Slow N, Slow P
****     FF-- Fast N, Fast P
****     SF-- Slow N, Fast P
****     FS-- Fast N, Slow P
**** To run this simulation, the files "model.cnr" and "inbuff.inc" are
**** required to be in the same directory as this netlist.
**** Temperature settings are: Typical 40C, Slow 100C, Fast -40C
****   These temperatures correspond to ambient temperatures of 25C, 85C, -40C.

.OPTIONS ACCT OPTS NOPAGE POST
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.05ns 20.0ns
**** The temperature is for the slow case
.TEMP 100
.LIB "model.cnr" SS

**** Input Signal and Power Supply Setup
**** Note: vccr and vbb are regulated internal voltages
**** Match up typ, min, or max voltages for corner sims
.PARAM  vcc_typ    = 3.300V
.PARAM  vcc_min    = 3.000V
.PARAM  vcc_max    = 3.600V

.PARAM  vccr_typ   = 2.513V
.PARAM  vccr_min   = 2.431V
.PARAM  vccr_max   = 2.594V

.PARAM  vbb_typ    = -0.764V
.PARAM  vbb_min    = -0.828V
.PARAM  vbb_max    = -0.656V

.PARAM  gnd        = 0.0V
********************************************************************************
.PARAM  vcc        = vcc_min
.PARAM  vccr       = vccr_min
.PARAM  vbb        = vbb_min
********************************************************************************
Vvcc     vcc   0  DC = vcc
Vvccr    vccr  0  DC = vccr
Vvbb     vbb   0  DC = vbb

Ven   rcvr_en  0  DC = vccr
** Enable signal is active high

Vin     in_pkg  0  PWL 0.0ns vcc 0.1ns gnd 7.0ns gnd 7.1ns vcc 14.0ns vcc R
** Vin toggles the input from 1 to 0 at ~143Mhz/2 = 71.5MHz

* Output load circuits:
xi0 rcvr_en pad rcvr_out gnd vbb vccr vcc inbuff

* Refer to the IBIS model for specific package parasitic values.
r_pkg pad net1 r=350e-3
l_pkg net1 in_pkg l=5.60e-9
c_pkg in_pkg gnd c=0.82e-12

.alter typ
.PARAM  vcc         = vcc_typ
.PARAM  vccr        = vccr_typ
.PARAM  vbb         = vbb_typ
.temp 40
.lib "model.cnr" TT

.alter fast
.PARAM  vcc         = vcc_max
.PARAM  vccr        = vccr_max
.PARAM  vbb         = vbb_max
.temp -40
.lib "model.cnr" FF

.END
